@@ -8,6 +8,7 @@ from .baseviews import expose, BaseView, BaseCRUDView
 
 log = logging.getLogger(__name__)
 
+
 class IndexView(BaseView):
     """
         A simple view that implements the index for the site
@@ -19,7 +20,7 @@ class IndexView(BaseView):
 
     @expose('/')
     def index(self):
-        return render_template(self.index_template, baseapp = self.baseapp)
+        return render_template(self.index_template, baseapp=self.baseapp)
 
 
 class SimpleFormView(BaseView):
@@ -33,7 +34,7 @@ class SimpleFormView(BaseView):
     """
 
     form_template = 'appbuilder/general/model/edit.html'
-    
+
     edit_widget = FormWidget
     form_title = ''
     """ The form title to be displayed """
@@ -42,7 +43,7 @@ class SimpleFormView(BaseView):
     form = None
     """ The WTF form to render """
     form_fieldsets = None
-    
+
     def _init_vars(self):
         self.form_columns = self.form_columns or []
         self.form_fieldsets = self.form_fieldsets or []
@@ -54,21 +55,21 @@ class SimpleFormView(BaseView):
         else:
             if not self.form_columns:
                 self.form_columns = list_cols
-        
-    
+
+
     @expose("/form", methods=['GET'])
     @has_access
     def this_form_get(self):
         self._init_vars()
         form = self.form.refresh()
-        
+
         self.form_get(form)
-        widgets = self._get_edit_widget(form = form)
+        widgets = self._get_edit_widget(form=form)
         return render_template(self.form_template,
-            title = self.form_title,
-            widgets = widgets,
-            baseapp = self.baseapp
-            )
+                               title=self.form_title,
+                               widgets=widgets,
+                               baseapp=self.baseapp
+        )
 
     def form_get(self, form):
         """
@@ -81,18 +82,18 @@ class SimpleFormView(BaseView):
     def this_form_post(self):
         self._init_vars()
         form = self.form.refresh()
-        
+
         if form.validate_on_submit():
             self.form_post(form)
             return redirect(self._get_redirect())
         else:
-            widgets = self._get_edit_widget(form = form)
+            widgets = self._get_edit_widget(form=form)
             return render_template(
-                    self.form_template,
-                    title = self.form_title,
-                    widgets = widgets,
-                    baseapp = self.baseapp
-                    )
+                self.form_template,
+                title=self.form_title,
+                widgets=widgets,
+                baseapp=self.baseapp
+            )
 
     def form_post(self, form):
         """
@@ -100,17 +101,16 @@ class SimpleFormView(BaseView):
         """
         pass
 
-    def _get_edit_widget(self, form = None, exclude_cols = [], widgets = {}):
-        widgets['edit'] = self.edit_widget(route_base = self.route_base,
-                                                form = form,
-                                                include_cols = self.form_columns,
-                                                exclude_cols = exclude_cols,
-                                                fieldsets = self.form_fieldsets
-                                                )         
+    def _get_edit_widget(self, form=None, exclude_cols=[], widgets={}):
+        widgets['edit'] = self.edit_widget(route_base=self.route_base,
+                                           form=form,
+                                           include_cols=self.form_columns,
+                                           exclude_cols=exclude_cols,
+                                           fieldsets=self.form_fieldsets
+        )
         return widgets
 
 
-
 class GeneralView(BaseCRUDView):
     """
         This is the CRUD generic view. If you want to automatically implement create, edit, delete, show, and list from your database tables, inherit your views from this class.
@@ -121,64 +121,69 @@ class GeneralView(BaseCRUDView):
     def __init__(self, **kwargs):
         super(GeneralView, self).__init__(**kwargs)
 
-    
+
     """
     --------------------------------
             LIST
     --------------------------------
     """
+
     @expose('/list/')
     @has_access
     def list(self):
 
         widgets = self._list()
         return render_template(self.list_template,
-                                        title = self.list_title,
-                                        widgets = widgets,
-                                        baseapp = self.baseapp)
+                               title=self.list_title,
+                               widgets=widgets,
+                               baseapp=self.baseapp)
 
     """
     --------------------------------
             SHOW
     --------------------------------
     """
+
     @expose('/show/<pk>', methods=['GET'])
     @has_access
     def show(self, pk):
 
-        widgets = self._show(pk)        
+        widgets = self._show(pk)
         return render_template(self.show_template,
-                           pk = pk,
-                           title = self.show_title,
-                           widgets = widgets,
-                           baseapp = self.baseapp,
-                           related_views = self._related_views)
+                               pk=pk,
+                               title=self.show_title,
+                               widgets=widgets,
+                               baseapp=self.baseapp,
+                               related_views=self._related_views)
 
 
-    
     """
     ---------------------------
             ADD
     ---------------------------
     """
+
     @expose('/add', methods=['GET', 'POST'])
     @has_access
     def add(self):
 
         widget = self._add()
+        log.debug("ADD {}".format(widget))
         if not widget:
+            log.debug("GOING TO ADD {}".format(self._get_redirect()))
             return redirect(self._get_redirect())
         else:
             return render_template(self.add_template,
-                                   title = self.add_title,
-                                   widgets = widget,
-                                   baseapp = self.baseapp)    
+                                   title=self.add_title,
+                                   widgets=widget,
+                                   baseapp=self.baseapp)
 
     """
     ---------------------------
             EDIT
     ---------------------------
     """
+
     @expose('/edit/<pk>', methods=['GET', 'POST'])
     @has_access
     def edit(self, pk):
@@ -187,18 +192,18 @@ class GeneralView(BaseCRUDView):
             return redirect(self._get_redirect())
         else:
             return render_template(self.edit_template,
-                        title = self.edit_title,
-                        widgets = widgets,
-                        baseapp = self.baseapp,
-                        related_views = self._related_views)
+                                   title=self.edit_title,
+                                   widgets=widgets,
+                                   baseapp=self.baseapp,
+                                   related_views=self._related_views)
 
-        
 
     """
     ---------------------------
             DELETE
     ---------------------------
     """
+
     @expose('/delete/<pk>')
     @has_access
     def delete(self, pk):
@@ -209,9 +214,9 @@ class GeneralView(BaseCRUDView):
     @expose('/download/<string:filename>')
     @has_access
     def download(self, filename):
-        return send_file(self.baseapp.app.config['UPLOAD_FOLDER'] + filename, 
-                    attachment_filename = uuid_originalname(filename), 
-                    as_attachment = True)
+        return send_file(self.baseapp.app.config['UPLOAD_FOLDER'] + filename,
+                         attachment_filename=uuid_originalname(filename),
+                         as_attachment=True)
 
 
     @expose('/action/<string:name>/<pk>')
@@ -221,9 +226,9 @@ class GeneralView(BaseCRUDView):
             action = self.actions.get(name)
             return action.func(self.datamodel.get(pk))
         else:
-            flash("Access is Denied %s %s" % (name, self.__class__.__name__),"danger")
+            flash("Access is Denied %s %s" % (name, self.__class__.__name__), "danger")
             return redirect('.')
-        
+
 
 class CompactCRUDMixin(BaseCRUDView):
     """
@@ -237,10 +242,10 @@ class CompactCRUDMixin(BaseCRUDView):
         """ get joined base filter and current active filter for query """
         widgets = super(CompactCRUDMixin, self)._get_list_widget(**args)
         ret_widget = {}
-        ret_widget['list'] = GroupFormListWidget(list_widget=widgets.get('list'), 
-                                    form_widget = self._session_form_widget,
-                                    form_action = self._session_form_action,
-                                    form_title = self._session_form_title)
+        ret_widget['list'] = GroupFormListWidget(list_widget=widgets.get('list'),
+                                                 form_widget=self._session_form_widget,
+                                                 form_action=self._session_form_action,
+                                                 form_title=self._session_form_title)
         return ret_widget
 
     @expose('/list/', methods=['GET', 'POST'])
@@ -248,9 +253,9 @@ class CompactCRUDMixin(BaseCRUDView):
     def list(self):
         list_widgets = self._list()
         return render_template(self.list_template,
-                                        title = self.list_title,
-                                        widgets = list_widgets,
-                                        baseapp = self.baseapp)
+                               title=self.list_title,
+                               widgets=list_widgets,
+                               baseapp=self.baseapp)
 
     @expose('/add/', methods=['GET', 'POST'])
     @has_access
@@ -274,7 +279,7 @@ class CompactCRUDMixin(BaseCRUDView):
         if not widgets:
             self._session_form_action = ''
             self._session_form_widget = None
-            
+
             return redirect(self._get_redirect())
         else:
             self._session_form_widget = widgets.get('edit')
